pub struct FinishConfigurationC2s;Expand description
Sent by the client to the server to finish the configuration process. This
packet is sent after the server sends a FinishConfigurationS2c
packet.
We should move to the play state after this packet is received.